@@ -23,9 +23,7 @@
 #include "cipher.h"
 
 typedef struct {
-    MD_HANDLE *md;	/* catch all */
-    MD5HANDLE md5;	/* if !NULL create md5	*/
-    RMDHANDLE rmd160;	/* if !NULL create rmd160  */
+    MD_HANDLE md;      /* catch all */
     size_t maxbuf_size;
 } md_filter_context_t;
 
